==> forestry_1.7.10-2.4.2.40-dev.jar: forestry/apiculture/gadgets/TileSwarm.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/gpl-3.0.txt
 * 
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.apiculture.gadgets;

import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.tileentity.TileEntity;

import forestry.core.utils.InventoryAdapter;

public class TileSwarm extends TileEntity {

	public InventoryAdapter contained = new InventoryAdapter(2, "Contained");

	@Override
	public boolean canUpdate() {
		return false;
	}

	public TileSwarm setContained(ItemStack[] bees) {
		for (ItemStack itemstack : bees)
			contained.addStack(itemstack, false, true);

		return this;
	}

	public boolean containsBees() {
		for (int i = 0; i < contained.getSizeInventory(); i++)
			if (contained.getStackInSlot(i) != null)
				return true;

		return false;
	}

	@Override
	public void readFromNBT(NBTTagCompound nbttagcompound) {
		super.readFromNBT(nbttagcompound);
		contained.readFromNBT(nbttagcompound);
	}

	@Override
	public void writeToNBT(NBTTagCompound nbttagcompound) {
		super.writeToNBT(nbttagcompound);
		contained.writeToNBT(nbttagcompound);
	}

}

==> forestry_1.7.10-3.4.0.7-dev.jar: forestry/apiculture/gadgets/TileSwarm.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 * 
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.apiculture.gadgets;

import forestry.core.inventory.InvTools;
import forestry.core.inventory.InventoryAdapter;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.world.EnumSkyBlock;

public class TileSwarm extends TileEntity {

	public final InventoryAdapter contained = new InventoryAdapter(2, "Contained");

	@Override
	public boolean canUpdate() {
		return true;
	}

	// Hack to make sure that hives glow.
	// TODO: remove when Mojang fixes this bug: https://bugs.mojang.com/browse/MC-3329
	// Hives should not need to tick normally.
	private boolean updatedLight;

	@Override
	public void updateEntity() {
		super.updateEntity();

		if (worldObj.isRemote && !updatedLight && worldObj.getWorldTime() % 20 == 0) {
			updatedLight = worldObj.updateLightByType(EnumSkyBlock.Block, xCoord, yCoord, zCoord);
		}
	}

	public TileSwarm setContained(ItemStack[] bees) {
		for (ItemStack itemstack : bees)
			InvTools.addStack(contained, itemstack, false, true);

		return this;
	}

	public boolean containsBees() {
		for (int i = 0; i < contained.getSizeInventory(); i++)
			if (contained.getStackInSlot(i) != null)
				return true;

		return false;
	}

	@Override
	public void readFromNBT(NBTTagCompound nbttagcompound) {
		super.readFromNBT(nbttagcompound);
		contained.readFromNBT(nbttagcompound);
	}

	@Override
	public void writeToNBT(NBTTagCompound nbttagcompound) {
		super.writeToNBT(nbttagcompound);
		contained.writeToNBT(nbttagcompound);
	}

}
